@@ -1,6 +1,10 @@
+import warnings
+from functools import cache
+
 import bcp47
 
 
+@cache
 def is_bcp47(language_ietf: str) -> bool:
     """
     Check if a given language tag is a valid BCP 47 language tag.
@@ -15,6 +19,11 @@ def is_bcp47(language_ietf: str) -> bool:
     bool
         True if the language tag is a valid BCP 47 language tag, False otherwise.
     """
+    warnings.warn(
+        "The function 'is_bcp47' is deprecated and will be removed in a future release.",
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
     if language_ietf != "und":
         return language_ietf in bcp47.languages.values()
     else:  # noqa: RET505
