@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from iso639 import languages
+from iso639 import Language, LanguageNotFoundError
 
 
 def is_iso639_2(language: str) -> bool:
@@ -16,7 +16,7 @@ def is_iso639_2(language: str) -> bool:
         True if the language code is valid according to ISO 639-2, False otherwise.
     """
     try:
-        languages.get(part2b=language)
+        Language.from_part2b(language)
         return True  # noqa: TRY300
-    except KeyError:
+    except LanguageNotFoundError:
         return False
