@@ -10,7 +10,7 @@ Create and mux a new MKV. This example takes an standalone video and audio track
 >>> mkv = MKVFile()
 >>> mkv.add_track('/path/to/track.h264')
 >>> mkv.add_track(MKVTrack('/path/to/another/track.aac'))
->>> mkv.mux('/path/to/output.mkv')
+>> mkv.mux('/path/to/output.mkv')
 
 Generate the mkvmerge command to mux an MKV. This is example is identical to the first example except the command is
 only generated, not executed.
@@ -37,11 +37,12 @@ Combine two MKVs. This example takes two existing MKVs and combines their tracks
 
 from __future__ import annotations
 
-import json
 import logging
 import os
 import subprocess as sp
+from collections.abc import Iterable, Sequence
 from pathlib import Path
+from typing import Any, TypeVar, cast
 
 import bitmath
 
@@ -50,11 +51,19 @@ from pymkv.MKVAttachment import MKVAttachment
 from pymkv.MKVTrack import MKVTrack
 from pymkv.Timestamp import Timestamp
 from pymkv.utils import prepare_mkvtoolnix_path
-from pymkv.Verifications import checking_file_path, verify_mkvmerge, verify_supported
+from pymkv.Verifications import (
+    checking_file_path,
+    get_file_info,
+    verify_mkvmerge,
+    verify_supported,
+)
+
+T = TypeVar("T")
 
 
 class MKVFile:
-    """A class that represents an MKV file.
+    """
+    A class that represents an MKV file.
 
     The :class:`~pymkv.MKVFile` class can either import a pre-existing MKV file or create a new one. After an
     :class:`~pymkv.MKVFile` object has been instantiated, :class:`~pymkv.MKVTrack` objects or other
@@ -87,45 +96,72 @@ class MKVFile:
         Raised if the path to mkvmerge could not be verified.
     """
 
-    def __init__(  # noqa: C901, PLR0912
+    def __init__(
         self,
         file_path: str | os.PathLike | None = None,
         title: str | None = None,
-        mkvmerge_path: str | list | os.PathLike | None = "mkvmerge",
+        mkvmerge_path: str | os.PathLike | Iterable[str] = "mkvmerge",
     ) -> None:
-        self.mkvmerge_path: list[str] = prepare_mkvtoolnix_path(mkvmerge_path)
+        self.mkvmerge_path: tuple[str, ...] = prepare_mkvtoolnix_path(mkvmerge_path)
         self.title = title
-        self._chapters_file = None
-        self._chapter_language = None
-        self._global_tags_file = None
-        self._link_to_previous_file = None
-        self._link_to_next_file = None
+        self._chapters_file: str | None = None
+        self._chapter_language: str | None = None
+        self._global_tags_file: str | None = None
+        self._link_to_previous_file: str | None = None
+        self._link_to_next_file: str | None = None
         self.tracks: list[MKVTrack] = []
-        self.attachments = []
+        self.attachments: list[MKVAttachment] = []
         self._number_file = 0
+        self._info_json: dict[str, Any] | None = None
+        self._global_tag_entries = 0
+
+        # exclusions
+        self.no_track_statistics_tags = False
 
         if not verify_mkvmerge(mkvmerge_path=self.mkvmerge_path):
             msg = "mkvmerge is not at the specified path, add it there or changed mkvmerge_path property"
             raise FileNotFoundError(msg)
 
-        if not verify_supported(file_path, mkvmerge_path=self.mkvmerge_path):
-            msg = f"The file '{file_path}' is not a valid Matroska file or is not supported."
-            raise ValueError(msg)
-
         if file_path is not None:
+            if not verify_supported(file_path, mkvmerge_path=self.mkvmerge_path):
+                msg = f"The file '{file_path}' is not a valid Matroska file or is not supported."
+                raise ValueError(msg)
             # add file title
             file_path = checking_file_path(file_path)
             try:
-                info_json = json.loads(sp.check_output([*self.mkvmerge_path, "-J", file_path]).decode())  # noqa: S603
+                info_json = get_file_info(
+                    file_path,
+                    self.mkvmerge_path,
+                    check_path=False,
+                )
+                self._info_json = info_json
             except sp.CalledProcessError as e:
                 error_output = e.output.decode()
-                raise sp.CalledProcessError(e.returncode, e.cmd, output=error_output) from e
+                raise sp.CalledProcessError(
+                    e.returncode,
+                    e.cmd,
+                    output=error_output,
+                ) from e
             if self.title is None and "title" in info_json["container"]["properties"]:
                 self.title = info_json["container"]["properties"]["title"]
 
+            self._global_tag_entries = sum(t["num_entries"] for t in info_json.get("global_tags", []))
+
+            # dictionary associating track_id to the number of tag entries:
+            track_tag_entries: dict[int, int] = {
+                t["track_id"]: t["num_entries"] for t in self._info_json.get("track_tags", [])
+            }
+
             # add tracks with info
             for track in info_json["tracks"]:
-                new_track = MKVTrack(file_path, track_id=track["id"], mkvmerge_path=self.mkvmerge_path)
+                track_id = track["id"]
+                new_track = MKVTrack(
+                    file_path,
+                    track_id=track_id,
+                    mkvmerge_path=self.mkvmerge_path,
+                    existing_info=self._info_json,
+                    tag_entries=track_tag_entries.get(track_id, 0),
+                )
                 if "track_name" in track["properties"]:
                     new_track.track_name = track["properties"]["track_name"]
                 if "language" in track["properties"]:
@@ -144,52 +180,67 @@ class MKVFile:
                     new_track.flag_visual_impaired = track["properties"]["flag_visual_impaired"]
                 if "flag_original" in track["properties"]:
                     new_track.flag_original = track["properties"]["flag_original"]
+
                 self.add_track(new_track, new_file=False)
 
         # split options
-        self._split_options = []
+        self._split_options: list[str] = []
 
     def __repr__(self) -> str:
         """
-        Return a string representation of the object.
+        Return a string representation of the MKVFile object.
 
-        :returns: A string representation of the object.
-        :rtype: str
+        Returns:
+            str: A string representation of the object's attributes.
         """
         return repr(self.__dict__)
 
     @property
-    def chapter_language(self) -> str:
-        """str: The language code of the chapters in the :class:`~pymkv.MKVFile` object.
+    def chapter_language(self) -> str | None:
+        """
+        Get the language code of the chapters in the MKVFile object.
 
-        Raises
-        ------
-        ValueError
-            Raised if not a valid ISO 639-2 language code.
+        Returns:
+            str: The ISO 639-2 language code of the chapters.
+
+        Raises:
+            ValueError: If the stored language code is not a valid ISO 639-2 language code.
         """
         return self._chapter_language
 
     @chapter_language.setter
-    def chapter_language(self, language: str) -> None:
+    def chapter_language(self, language: str | None) -> None:
         """
-        Parameters
-        ----------
-        language : str
-            The language code for the chapter.
-            Must be an ISO639-2 language code.
+        Set the language code of the chapters in the MKVFile object.
 
-        Raises
-        ------
-        ValueError
-            If the provided language code is not a valid ISO639-2 language code.
+        Args:
+            language (str): The language code for the chapters. Must be a valid ISO 639-2 language code.
+
+        Raises:
+            ValueError: If the provided language code is not a valid ISO 639-2 language code.
         """
         if language is not None and not is_iso639_2(language):
-            msg = "not an ISO639-2 language code"
+            msg = "The provided language code is not a valid ISO 639-2 language code."
             raise ValueError(msg)
         self._chapter_language = language
 
-    def command(self, output_path: str, subprocess: bool = False) -> str | list:  # noqa: C901, PLR0912, PLR0915
-        """Generates an mkvmerge command based on the configured :class:`~pymkv.MKVFile`.
+    @property
+    def global_tag_entries(self) -> int:
+        """
+        Gets the number of global tag entries in the MKVFile object.
+
+        Returns:
+            int: The number of entries.
+        """
+        return self._global_tag_entries
+
+    def command(  # noqa: PLR0912,PLR0915
+        self,
+        output_path: str,
+        subprocess: bool = False,
+    ) -> str | list:
+        """
+        Generates an mkvmerge command based on the configured :class:`~pymkv.MKVFile`.
 
         Parameters
         ----------
@@ -208,15 +259,22 @@ class MKVFile:
         command = [*self.mkvmerge_path, "-o", output_path]
         if self.title is not None:
             command.extend(["--title", self.title])
+        if self.no_track_statistics_tags:
+            # Do not write tags with track statistics.
+            command.append("--disable-track-statistics-tags")
         track_order = []
         for track in self.tracks:
             # for track_order
             track_order.append(f"{track.file_id}:{track.track_id}")
             # flags
             if track.track_name is not None:
-                command.extend(["--track-name", f"{track.track_id!s}:{track.track_name}"])
+                command.extend(
+                    ["--track-name", f"{track.track_id!s}:{track.track_name}"],
+                )
             if track.language_ietf is not None:
-                command.extend(["--language", f"{track.track_id!s}:{track.language_ietf}"])
+                command.extend(
+                    ["--language", f"{track.track_id!s}:{track.language_ietf}"],
+                )
             elif track.language is not None:
                 command.extend(["--language", f"{track.track_id!s}:{track.language}"])
             if track.sync is not None:
@@ -247,6 +305,10 @@ class MKVFile:
                 command.extend(["--commentary-flag", f"{track.track_id!s}:1"])
             else:
                 command.extend(["--commentary-flag", f"{track.track_id!s}:0"])
+            if track.compression is not None:
+                command.extend(
+                    ["--compression", f"{track.track_id!s}:{'zlib' if track.compression else 'none'}"],
+                )
 
             # remove extra tracks
             if track.track_type == "audio":
@@ -311,8 +373,9 @@ class MKVFile:
 
         return command if subprocess else " ".join(command)
 
-    def mux(self, output_path: str | os.PathLike, silent: bool = False) -> int:
-        """Mixes the specified :class:`~pymkv.MKVFile`.
+    def mux(self, output_path: str | os.PathLike, silent: bool = False, ignore_warning: bool = False) -> int:
+        """
+        Mixes the specified :class:`~pymkv.MKVFile`.
 
         Parameters
         ----------
@@ -320,6 +383,8 @@ class MKVFile:
             The path to be used as the output file in the mkvmerge command.
         silent : bool, optional
             By default the mkvmerge output will be shown unless silent is True.
+        ignore_warning : bool, optional
+            If set to True, the muxing process will ignore any warnings (exit code 1) from mkvmerge.
         Returns
         -------
         int of Any
@@ -328,10 +393,11 @@ class MKVFile:
         Raises
         ------
         ValueError
-            Raised if the external mkvmerge command fails with a non-zero exit status.
-            This includes scenarios such as invalid command arguments, errors in
-            processing the :class:`~pymkv.MKVFile`, or issues with output file writing. The error
-            message provides details about the failure based on the output of the command.
+            Raised if the external mkvmerge command fails with a non-zero exit status
+            (except for warnings when ignore_warning is True). This includes scenarios
+            such as invalid command arguments, errors in processing the :class:`~pymkv.MKVFile`,
+            or issues with output file writing. The error message provides details about
+            the failure based on the output of the command.
         """
         output_path = str(Path(output_path).expanduser())
         args = self.command(output_path, subprocess=True)
@@ -342,19 +408,30 @@ class MKVFile:
         proc = sp.Popen(args, stdout=stdout, stderr=stderr)  # noqa: S603
         _, err = proc.communicate()
 
-        if proc.returncode:
+        if proc.returncode != 0:
+            # Handle warnings (exit code 1) if ignore_warning is True
+            if proc.returncode == 1 and ignore_warning:
+                logging.warning("Process completed with warnings, but ignored as per the setting.")
+                return proc.returncode
+
+            # For other non-zero exit codes, raise an exception
             error_message = f"Command failed with non-zero exit status {proc.returncode}"
             if err:
                 error_details = err.decode()
                 error_message += f"\nError Output:\n{error_details}"
                 logging.error(error_details)
-            logging.error("Non-zero exit status when running %s (%s)", args, proc.returncode)
+            logging.error(
+                "Non-zero exit status when running %s (%s)",
+                args,
+                proc.returncode,
+            )
             raise ValueError(error_message)
 
         return proc.returncode
 
     def add_file(self, file: MKVFile | str | os.PathLike) -> None:
-        """Add an MKV file into the :class:`~pymkv.MKVFile` object.
+        """
+        Add an MKV file into the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -383,7 +460,8 @@ class MKVFile:
         self.order_tracks_by_file_id()
 
     def add_track(self, track: str | MKVTrack, new_file: bool = True) -> None:
-        """Add a track to the :class:`~pymkv.MKVFile`.
+        """
+        Add a track to the :class:`~pymkv.MKVFile`.
 
         Parameters
         ----------
@@ -399,7 +477,11 @@ class MKVFile:
             Raised if `track` is not a string-like path to a track file or an :class:`~pymkv.MKVTrack`.
         """
         if isinstance(track, str):
-            new_track = MKVTrack(track, mkvmerge_path=self.mkvmerge_path)
+            new_track = MKVTrack(
+                track,
+                mkvmerge_path=self.mkvmerge_path,
+                existing_info=self._info_json,
+            )
             self._extracted_from_add_track(new_track, new_file)
         elif isinstance(track, MKVTrack):
             self._extracted_from_add_track(track, new_file)
@@ -408,14 +490,19 @@ class MKVFile:
             raise TypeError(msg)
         self.order_tracks_by_file_id()
 
-    def _extracted_from_add_track(self, track: MKVTrack, new_file: bool = False) -> None:
+    def _extracted_from_add_track(
+        self,
+        track: MKVTrack,
+        new_file: bool = False,
+    ) -> None:
         if new_file:
             self._number_file += 1
         track.file_id = self._number_file
         self.tracks.append(track)
 
     def add_attachment(self, attachment: str | MKVAttachment) -> None:
-        """Add an attachment to the :class:`~pymkv.MKVFile`.
+        """
+        Add an attachment to the :class:`~pymkv.MKVFile`.
 
         Parameters
         ----------
@@ -436,8 +523,9 @@ class MKVFile:
             msg = "Attachment is not str of MKVAttachment"
             raise TypeError(msg)
 
-    def get_track(self, track_num: int | None = None) -> MKVTrack:
-        """Get a :class:`~pymkv.MKVTrack` from the :class:`~pymkv.MKVFile` object.
+    def get_track(self, track_num: int | None = None) -> MKVTrack | list[MKVTrack]:
+        """
+        Get a :class:`~pymkv.MKVTrack` from the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -454,7 +542,8 @@ class MKVFile:
         return self.tracks if track_num is None else self.tracks[track_num]
 
     def move_track_front(self, track_num: int) -> None:
-        """Set a track as the first in the :class:`~pymkv.MKVFile` object.
+        """
+        Set a track as the first in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -473,7 +562,8 @@ class MKVFile:
         self.order_tracks_by_file_id()
 
     def move_track_end(self, track_num: int) -> None:
-        """Set as track as the last in the :class:`~pymkv.MKVFile` object.
+        """
+        Set as track as the last in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -492,7 +582,8 @@ class MKVFile:
         self.order_tracks_by_file_id()
 
     def move_track_forward(self, track_num: int) -> None:
-        """Move a track forward in the :class:`~pymkv.MKVFile` object.
+        """
+        Move a track forward in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -507,11 +598,15 @@ class MKVFile:
         if not 0 <= track_num < len(self.tracks) - 1:
             msg = "Track index out of range"
             raise IndexError(msg)
-        self.tracks[track_num], self.tracks[track_num + 1] = self.tracks[track_num + 1], self.tracks[track_num]
+        self.tracks[track_num], self.tracks[track_num + 1] = (
+            self.tracks[track_num + 1],
+            self.tracks[track_num],
+        )
         self.order_tracks_by_file_id()
 
     def move_track_backward(self, track_num: int) -> None:
-        """Move a track backward in the :class:`~pymkv.MKVFile` object.
+        """
+        Move a track backward in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -526,11 +621,15 @@ class MKVFile:
         if not 0 < track_num < len(self.tracks):
             msg = "Track index out of range"
             raise IndexError(msg)
-        self.tracks[track_num], self.tracks[track_num - 1] = self.tracks[track_num - 1], self.tracks[track_num]
+        self.tracks[track_num], self.tracks[track_num - 1] = (
+            self.tracks[track_num - 1],
+            self.tracks[track_num],
+        )
         self.order_tracks_by_file_id()
 
     def swap_tracks(self, track_num_1: int, track_num_2: int) -> None:
-        """Swap the position of two tracks in the :class:`~pymkv.MKVFile` object.
+        """
+        Swap the position of two tracks in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -549,11 +648,15 @@ class MKVFile:
         ):
             msg = "Track index out of range"
             raise IndexError(msg)
-        self.tracks[track_num_1], self.tracks[track_num_2] = self.tracks[track_num_2], self.tracks[track_num_1]
+        self.tracks[track_num_1], self.tracks[track_num_2] = (
+            self.tracks[track_num_2],
+            self.tracks[track_num_1],
+        )
         self.order_tracks_by_file_id()
 
     def replace_track(self, track_num: int, track: MKVTrack) -> None:
-        """Replace a track with another track in the :class:`~pymkv.MKVFile` object.
+        """
+        Replace a track with another track in the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -574,7 +677,8 @@ class MKVFile:
         self.order_tracks_by_file_id()
 
     def remove_track(self, track_num: int) -> None:
-        """Remove a track from the :class:`~pymkv.MKVFile` object.
+        """
+        Remove a track from the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -596,8 +700,13 @@ class MKVFile:
         """Remove all splitting options."""
         self._split_options = []
 
-    def split_size(self, size: bitmath.Bitmath | int, link: bool | None = False) -> None:
-        """Split the output file into parts by size.
+    def split_size(
+        self,
+        size: bitmath.Bitmath | int,
+        link: bool | None = False,
+    ) -> None:
+        """
+        Split the output file into parts by size.
 
         Parameters
         ----------
@@ -613,16 +722,17 @@ class MKVFile:
             Raised if if `size` is not a bitmath object or an integer.
         """
         if getattr(size, "__module__", None) == bitmath.__name__:
-            size = size.bytes
+            size = cast(bitmath.Bitmath, size).bytes
         elif not isinstance(size, int):
             msg = "size is not a bitmath object or integer"
             raise TypeError(msg)
         self._split_options = ["--split", f"size:{size}"]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
     def split_duration(self, duration: str | int, link: bool | None = False) -> None:
-        """Split the output file into parts by duration.
+        """
+        Split the output file into parts by duration.
 
         Parameters
         ----------
@@ -634,14 +744,19 @@ class MKVFile:
         """
         self._split_options = ["--split", f"duration:{Timestamp(duration)!s}"]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
-    def split_timestamps(self, *timestamps: str | int | list | tuple, link: bool | None = False) -> None:
-        """Split the output file into parts by timestamps.
+    def split_timestamps(
+        self,
+        *timestamps: Iterable[str | int],
+        link: bool | None = False,
+    ) -> None:
+        """
+        Split the output file into parts by timestamps.
 
         Parameters
         ----------
-        *timestamps : str, int, list, tuple
+        *timestamps : Iterable[str | int]
             The timestamps to split the file by. Can be passed as any combination of strs and ints, inside or outside
             an :obj:`Iterable` object. Any lists will be flattened. Timestamps must be ints, representing seconds,
             or strs in the form HH:MM:SS.nnnnnnnnn. The timestamp string requires formatting of at least M:S.
@@ -654,8 +769,8 @@ class MKVFile:
             Raised if invalid or improperly formatted timestamps are passed in for `*timestamps`.
         """
         # check if in timestamps form
-        ts_flat = MKVFile.flatten(timestamps)
-        if len(ts_flat) == 0:
+        ts_flat: list[str | int] = MKVFile.flatten(timestamps)
+        if not ts_flat:
             msg = f'"{timestamps}" are not properly formatted timestamps'
             raise ValueError(msg)
         if None in ts_flat:
@@ -672,10 +787,15 @@ class MKVFile:
             ts_string += f"{Timestamp(ts)!s},"
         self._split_options = ["--split", ts_string[:-1]]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
-    def split_frames(self, *frames: int | list | tuple, link: bool | None = False) -> None:
-        """Split the output file into parts by frames.
+    def split_frames(
+        self,
+        *frames: int | Iterable[int],
+        link: bool | None = False,
+    ) -> None:
+        """
+        Split the output file into parts by frames.
 
         Parameters
         ----------
@@ -693,8 +813,8 @@ class MKVFile:
             Raised if improperly formatted frames are passed in for `*frames`.
         """
         # check if in frames form
-        frames_flat = MKVFile.flatten(frames)
-        if len(frames_flat) == 0:
+        frames_flat: list[int] = MKVFile.flatten(frames)
+        if not frames_flat:
             msg = f'"{frames}" are not properly formatted frames'
             raise ValueError(msg)
         for f in frames_flat:
@@ -712,10 +832,15 @@ class MKVFile:
             f_string += f"{f!s},"
         self._split_options = ["--split", f_string[:-1]]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
-    def split_timestamp_parts(self, timestamp_parts: list | tuple, link: bool | None = False) -> None:  # noqa: C901
-        """Split the output in parts by time parts.
+    def split_timestamp_parts(
+        self,
+        timestamp_parts: Iterable[list[str] | tuple[str, ...]],
+        link: bool | None = False,
+    ) -> None:
+        """
+        Split the output in parts by time parts.
 
         Parameters
         ----------
@@ -733,8 +858,8 @@ class MKVFile:
         ValueError
             Raised if `timestamp_parts` contains improperly formatted parts.
         """
-        ts_flat = MKVFile.flatten(timestamp_parts)
-        if len(timestamp_parts) == 0:
+        ts_flat: list[str | int | Timestamp] = MKVFile.flatten(timestamp_parts)
+        if not ts_flat:
             msg = f'"{timestamp_parts}" are not properly formatted parts'
             raise ValueError(msg)
 
@@ -764,10 +889,15 @@ class MKVFile:
                 ts_string += "-" if index % 2 == 0 else ","
         self._split_options = ["--split", ts_string[:-1]]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
-    def split_parts_frames(self, frame_parts: list | tuple, link: bool | None = False) -> None:  # noqa: C901
-        """Split the output in parts by frames.
+    def split_parts_frames(
+        self,
+        frame_parts: Iterable[int],
+        link: bool | None = False,
+    ) -> None:
+        """
+        Split the output in parts by frames.
 
         Parameters
         ----------
@@ -786,8 +916,8 @@ class MKVFile:
         ValueError
             Raised if `frame_parts` contains improperly formatted parts.
         """
-        f_flat = MKVFile.flatten(frame_parts)
-        if len(frame_parts) == 0:
+        f_flat: list[int] = MKVFile.flatten(frame_parts)
+        if not f_flat:
             msg = f'"{frame_parts}" are not properly formatted parts'
             raise ValueError(msg)
         if None in f_flat[1:-1]:
@@ -798,8 +928,8 @@ class MKVFile:
                 msg = f'"{frame_parts}" are not properly formatted parts'
                 raise ValueError(msg)
         f_string = "parts:"
-        for f_set in frame_parts:
-            f_set = MKVFile.flatten(f_set)  # noqa: PLW2901
+        for fp in frame_parts:
+            f_set = MKVFile.flatten(fp)
             if not isinstance(f_set, (list, tuple)):
                 msg = "set is not of type list or tuple"
                 raise TypeError(msg)
@@ -817,10 +947,15 @@ class MKVFile:
                 f_string += "-" if index % 2 == 0 else ","
         self._split_options = ["--split", f_string[:-1]]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
-    def split_chapters(self, *chapters: int | list | tuple, link: bool | None = False) -> None:
-        """Split the output file into parts by chapters.
+    def split_chapters(
+        self,
+        *chapters: int | Iterable[int],
+        link: bool = False,
+    ) -> None:
+        """
+        Split the output file into parts by chapters.
 
         Parameters
         ----------
@@ -837,7 +972,7 @@ class MKVFile:
         ValueError
             Raised if `*chapters` contains improperly formatted chapters.
         """
-        c_flat = MKVFile.flatten(chapters)
+        c_flat: list[int] = MKVFile.flatten(chapters)
         if not chapters:
             self._split_options = ["--split", "chapters:all"]
             return
@@ -857,10 +992,11 @@ class MKVFile:
             c_string += f"{c!s},"
         self._split_options = ["--split", c_string[:-1]]
         if link:
-            self._split_options += "--link"
+            self._split_options.append("--link")
 
     def link_to_previous(self, file_path: str) -> None:
-        """Link the output file as the predecessor of the `file_path` file.
+        """
+        Link the output file as the predecessor of the `file_path` file.
 
         Parameters
         ----------
@@ -877,7 +1013,8 @@ class MKVFile:
         self._link_to_previous_file = checking_file_path(file_path)
 
     def link_to_next(self, file_path: str) -> None:
-        """Link the output file as the successor of the `file_path` file.
+        """
+        Link the output file as the successor of the `file_path` file.
 
         Parameters
         ----------
@@ -894,12 +1031,18 @@ class MKVFile:
         self._link_to_next_file = checking_file_path(file_path)
 
     def link_to_none(self) -> None:
-        """Remove all linking to previous and next options."""
+        """
+        Remove all linking to previous and next files.
+
+        This method clears any existing links to previous or next files,
+        effectively removing the file linking options for the current MKVFile object.
+        """
         self._link_to_previous_file = None
         self._link_to_next_file = None
 
     def chapters(self, file_path: str, language: str | None = None) -> None:
-        """Add a chapters file to the :class:`~pymkv.MKVFile` object.
+        """
+        Add a chapters file to the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -919,7 +1062,8 @@ class MKVFile:
         self.chapter_language = language
 
     def global_tags(self, file_path: str) -> None:
-        """Add global tags to the :class:`~pymkv.MKVFile` object.
+        """
+        Add global tags to the :class:`~pymkv.MKVFile` object.
 
         Parameters
         ----------
@@ -935,8 +1079,13 @@ class MKVFile:
         """
         self._global_tags_file = checking_file_path(file_path)
 
-    def track_tags(self, *track_ids: int | list | tuple, exclusive: bool | None = False) -> None:
-        """Include or exclude tags from specific tracks.
+    def track_tags(
+        self,
+        *track_ids: int | list | tuple,
+        exclusive: bool | None = False,
+    ) -> None:
+        """
+        Include or exclude tags from specific tracks.
 
         Parameters
         ----------
@@ -955,7 +1104,7 @@ class MKVFile:
         ValueError
             Raised if `*track_ids` are improperly formatted.
         """
-        ids_flat = MKVFile.flatten(track_ids)
+        ids_flat: list[int] = MKVFile.flatten(track_ids)
         if not track_ids:
             msg = f'"{track_ids}" are not properly formatted track ids'
             raise ValueError(msg)
@@ -970,37 +1119,58 @@ class MKVFile:
             self.tracks[tid].no_track_tags = True
 
     def no_chapters(self) -> None:
-        """Ignore the existing chapters of the :class:`~pymkv.MKVFile` object."""
+        """
+        Ignore the existing chapters of all tracks in the :class:`~pymkv.MKVFile` object.
+
+        This method sets the `no_chapters` attribute to True for all tracks in the MKVFile.
+        """
         for track in self.tracks:
             track.no_chapters = True
 
     def no_global_tags(self) -> None:
-        """Ignore the existing global tags of the :class:`~pymkv.MKVFile` object."""
+        """
+        Ignore the existing global tags of all tracks in the :class:`~pymkv.MKVFile` object.
+
+        This method sets the `no_global_tags` attribute to True for all tracks in the MKVFile.
+        """
         for track in self.tracks:
             track.no_global_tags = True
 
     def no_track_tags(self) -> None:
-        """Ignore the existing track tags of the :class:`~pymkv.MKVFile` object."""
+        """
+        Ignore the existing track tags of all tracks in the :class:`~pymkv.MKVFile` object.
+
+        This method sets the `no_track_tags` attribute to True for all tracks in the MKVFile.
+        """
         for track in self.tracks:
             track.no_track_tags = True
 
     def no_attachments(self) -> None:
-        """Ignore the existing attachments of the :class:`~pymkv.MKVFile` object."""
+        """
+        Ignore the existing attachments of all tracks in the :class:`~pymkv.MKVFile` object.
+
+        This method sets the `no_attachments` attribute to True for all tracks in the MKVFile.
+        """
         for track in self.tracks:
             track.no_attachments = True
 
     @staticmethod
-    def flatten(item: list | tuple) -> list:
-        """Flatten a list or a tuple.
+    def flatten(item: T | Iterable[T | Iterable[T]]) -> list[T]:
+        """
+        Flatten a list or a tuple.
 
         Takes a list or a tuple that contains other lists or tuples and flattens into a non-nested list.
 
         Examples
         --------
         >>> tup = ((1, 2), (3, (4, 5)))
-        >>> print(MKVFile.flatten(tup))
+        >>> MKVFile.flatten(tup)
         [1, 2, 3, 4, 5]
 
+        >>> tup = (["abc", "d"])
+        >>> MKVFile.flatten(tup)
+        ['abc', 'd']
+
         Parameters
         ----------
         item : list, tuple
@@ -1011,25 +1181,33 @@ class MKVFile:
         list
             A flattened version of `item`.
         """
-        if not isinstance(item, (list, tuple)):
-            return [item]
-        flat_list = []
-        for item in item:  # noqa: B020
-            flat_list.extend(MKVFile.flatten(item))
-        return flat_list
+
+        def _flatten(item: T | Iterable[T | Iterable[T]]) -> Iterable[T]:
+            if isinstance(item, Sequence) and not isinstance(item, str):
+                for subitem in item:
+                    yield from _flatten(subitem)
+            else:
+                yield cast(T, item)
+
+        return list(_flatten(item))
 
     def order_tracks_by_file_id(self) -> None:
         """
-        Orders tracks based on their file ID. Tracks from the same file will have the same file ID.
+        Assigns file IDs to tracks based on their source files.
 
-        This method first generates a list of unique file paths from the existing tracks.
-        Then, it assigns each track a file ID, which is the index of its file path in the unique list.
-        As a result, tracks from the same file will have the same file ID.
+        Creates a mapping of unique file paths to numeric IDs,
+        then assigns each track a file ID corresponding to its source file.
+        Tracks from the same file will have the same file ID.
+
+        This method modifies the file_id attribute of each track in self.tracks.
         """
-        unique_file_dict = {}
-        for track in self.tracks:
-            if track.file_path not in unique_file_dict:
-                unique_file_dict[track.file_path] = len(unique_file_dict)
+        unique_file_dict: dict[str, int] = {}
+        try:
+            for track in self.tracks:
+                if track.file_path not in unique_file_dict:
+                    unique_file_dict[track.file_path] = len(unique_file_dict)
 
-        for track in self.tracks:
-            track.file_id = unique_file_dict.get(track.file_path)
+            for track in self.tracks:
+                track.file_id = unique_file_dict[track.file_path]
+        except KeyError as e:
+            raise ValueError from e
