@@ -1,19 +1,25 @@
-# sheldon woodward
-# august 5, 2019
+from __future__ import annotations
 
-from pkg_resources import DistributionNotFound, get_distribution
+import importlib.metadata
 
 # package imports
 from .MKVAttachment import MKVAttachment
 from .MKVFile import MKVFile
 from .MKVTrack import MKVTrack
 from .Timestamp import Timestamp
-from .Verifications import checking_file_path, verify_matroska, verify_mkvmerge, verify_recognized, verify_supported
+from .Verifications import (
+    checking_file_path,
+    get_file_info,
+    verify_matroska,
+    verify_mkvmerge,
+    verify_recognized,
+    verify_supported,
+)
 
-# set the version number within the package using setuptools-scm
+# set the version number within the package using importlib
 try:
-    __version__ = get_distribution(__name__).version
-except DistributionNotFound:
+    __version__: str | None = importlib.metadata.version("pymkv2")
+except importlib.metadata.PackageNotFoundError:
     # package is not installed
     __version__ = None
 
@@ -22,9 +28,10 @@ __all__ = (
     "MKVFile",
     "MKVTrack",
     "Timestamp",
+    "checking_file_path",
+    "get_file_info",
     "verify_matroska",
     "verify_mkvmerge",
     "verify_recognized",
     "verify_supported",
-    "checking_file_path",
 )
